@@ -2,7 +2,7 @@
 asyncapi
 """
 
-__version__ = '0.11.1'
+__version__ = '0.12.0'
 from .api import AsyncApi, OperationsTypeHint
 from .builder import (
     build_api,
@@ -16,6 +16,8 @@ from .events import Event
 from .events.handler import EventsHandler
 from .exceptions import (
     ChannelOperationNotFoundError,
+    GCloudPubSubConsumerDisconnectError,
+    GCloudPubSubPublishTimeoutError,
     InvalidChannelError,
     OperationIdNotFoundError,
     ReferenceNotFoundError,
@@ -65,4 +67,6 @@ __all__ = [
     'run_docs',
     'EventsHandler',
     'Event',
+    'GCloudPubSubPublishTimeoutError',
+    'GCloudPubSubConsumerDisconnectError',
 ]
